BackoffStrategy enum

Strategies to compute delays between retry attempts.

Inheritance
Available extensions

Values

linear → const BackoffStrategy

Increases delay in a linear sequence (e.g. 1s, 2s, 3s).

exponential → const BackoffStrategy

Increases delay exponentially (e.g. 1s, 2s, 4s, 8s).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BackoffStrategy>
A constant List of the values in this enum, in order of their declaration.