WorkerResult class

Represents the execution results returned from a worker isolate.

Constructors

WorkerResult({SpidrResponse? response, String? error})
Creates a new WorkerResult representation.
const

Properties

error String?
Error details, if execution failed.
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
Whether the execution completed successfully.
no setter
response SpidrResponse?
The resulting response, if successful.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited