SpidrCapabilities class
Exposes the platform capability profile of the current running host.
Constructors
- SpidrCapabilities({required bool supportsProxy, required bool supportsLocalBrowser, required bool supportsRemoteBrowser, required bool supportsStorage, required bool supportsIsolates})
-
Creates a custom SpidrCapabilities instance.
const
- SpidrCapabilities.current()
-
Evaluates current environment and resolves capabilities.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsIsolates → bool
-
Whether the platform supports standard isolates for concurrent parallel execution.
final
- supportsLocalBrowser → bool
-
Whether the platform supports spawning process-level local browser engines (e.g. Windows, macOS, Linux, Server).
final
- supportsProxy → bool
-
Whether the platform supports raw socket-based proxy configuration (e.g. SOCKS5, HTTP proxies).
final
- supportsRemoteBrowser → bool
-
Whether the platform supports remote Chrome DevTools Protocol connections over WebSockets.
final
- supportsStorage → bool
-
Whether the platform supports local database engines (like SQLite/Isar).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited